summaryrefslogtreecommitdiff
path: root/TAO/tao/Stub.h
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2005-10-12 09:07:04 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2005-10-12 09:07:04 +0000
commit9838cc50651f5404da4ac7f0fc8060f6342e301d (patch)
treefba4a24642972158d18a2edd85a5f57debb718aa /TAO/tao/Stub.h
parentc5566edaa26c79f5adf3461e4b96596ebc10812f (diff)
downloadATCD-9838cc50651f5404da4ac7f0fc8060f6342e301d.tar.gz
ChangeLogTag: Wed Oct 12 08:42:12 UTC 2005 Johnny Willemsen <jwillemsen@remedy.nl>
Diffstat (limited to 'TAO/tao/Stub.h')
-rw-r--r--TAO/tao/Stub.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/TAO/tao/Stub.h b/TAO/tao/Stub.h
index d005c5c6457..ee0a989a50a 100644
--- a/TAO/tao/Stub.h
+++ b/TAO/tao/Stub.h
@@ -34,14 +34,13 @@
#endif /* HPUX && IOR */
// Forward declarations.
-class TAO_Sync_Strategy;
class TAO_Policy_Set;
class TAO_Profile;
-/// Forward declaration for ObjectKey
namespace TAO
{
class ObjectKey;
+ class Transport_Queueing_Strategy;
}
namespace IOP
@@ -89,9 +88,9 @@ public:
#endif /* TAO_HAS_CORBA_MESSAGING == 1 */
/// Return the sync strategy to be used in by the transport.
/// Selection will be based on the SyncScope policies.
- TAO_Sync_Strategy &sync_strategy (void);
+ TAO::Transport_Queueing_Strategy &transport_queueing_strategy (void);
/// All objref representations carry around a type ID.
CORBA::String_var type_id;
@@ -89,9 +88,9 @@ public:
#endif /* TAO_HAS_CORBA_MESSAGING == 1 */
- /// Return the sync strategy to be used in by the transport.
+ /// Return the queueing strategy to be used in by the transport.
/// Selection will be based on the SyncScope policies.